@@ -43,6 +43,7 @@
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
+#include "gdm-common.h"
 #include "gdm-chooser-server.h"
 
 #define GDM_CHOOSER_SERVER_DBUS_PATH      "/org/gnome/DisplayManager/ChooserServer"
@@ -131,7 +132,9 @@ handle_select_hostname (GdmChooserServer *chooser_server,
 
         reply = dbus_message_new_method_return (message);
         dbus_connection_send (connection, reply, NULL);
-        dbus_message_unref (reply);
+        if (reply != NULL) {
+                dbus_message_unref (reply);
+        }
 
         g_signal_emit (chooser_server, signals [HOSTNAME_SELECTED], 0, text);
 
@@ -147,7 +150,9 @@ handle_disconnect (GdmChooserServer *chooser_server,
 
         reply = dbus_message_new_method_return (message);
         dbus_connection_send (connection, reply, NULL);
-        dbus_message_unref (reply);
+        if (reply != NULL) {
+                dbus_message_unref (reply);
+        }
 
         g_signal_emit (chooser_server, signals [DISCONNECTED], 0);
 
@@ -219,7 +224,9 @@ do_introspect (DBusConnection *connection,
                 g_error ("No memory");
         }
 
-        dbus_message_unref (reply);
+        if (reply != NULL) {
+                dbus_message_unref (reply);
+        }
 
         return DBUS_HANDLER_RESULT_HANDLED;
 }
@@ -319,7 +326,7 @@ allow_user_function (DBusConnection *connection,
                 return FALSE;
         }
 
-        pwent = getpwnam (chooser_server->priv->user_name);
+        gdm_get_pwent_for_name (chooser_server->priv->user_name, &pwent);
         if (pwent == NULL) {
                 return FALSE;
         }
@@ -546,14 +553,14 @@ gdm_chooser_server_class_init (GdmChooserServerClass *klass)
                                          g_param_spec_string ("user-name",
                                                               "user name",
                                                               "user name",
-                                                              "gdm",
+                                                              GDM_USERNAME,
                                                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
         g_object_class_install_property (object_class,
                                          PROP_GROUP_NAME,
                                          g_param_spec_string ("group-name",
                                                               "group name",
                                                               "group name",
-                                                              "gdm",
+                                                              GDM_GROUPNAME,
                                                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
         signals [HOSTNAME_SELECTED] =
                 g_signal_new ("hostname-selected",
