@@ -668,6 +668,11 @@ reset_dialog (GdmGreeterLoginWindow *login_window,
                 /* If we don't have a user list jump straight to authenticate */
                 g_debug ("GdmGreeterLoginWindow: jumping straight to authenticate");
                 switch_mode (login_window, MODE_AUTHENTICATION);
+
+                g_debug ("Starting PAM conversation since no local users");
+                g_signal_emit (G_OBJECT (login_window), signals[USER_SELECTED],
+                               0, GDM_USER_CHOOSER_USER_OTHER);
+                g_signal_emit (login_window, signals[BEGIN_VERIFICATION], 0);
         } else {
                 switch_mode (login_window, dialog_mode);
         }
@@ -702,7 +707,8 @@ gdm_greeter_login_window_ready (GdmGreeterLoginWindow *login_window)
         set_focus (GDM_GREETER_LOGIN_WINDOW (login_window));
 
         /* If we are retrying a previously selected user */
-        if (login_window->priv->dialog_mode != MODE_SELECTION) {
+        if (!login_window->priv->user_list_disabled &&
+            login_window->priv->dialog_mode == MODE_AUTHENTICATION) {
                 retry_login (login_window);
         } else {
                 /* If the user list is disabled, then start the PAM conversation */
@@ -1090,6 +1096,7 @@ file_read_one_line (const char *filename)
 
         if (fgets (buf, sizeof (buf), f) == NULL) {
                 g_warning ("Unable to read from file %s", filename);
+                goto out;
         }
 
         line = g_strdup (buf);
@@ -1109,6 +1116,7 @@ static const char *known_etc_info_files [] = {
         "debian_version",
         "mandriva-release",
         "slackware-version",
+        "system-release",
         NULL
 };
 
@@ -1130,6 +1138,14 @@ get_system_version (void)
                         version = g_strdup (output);
                 }
                 version = g_strstrip (version);
+
+                /* lsb_release returns (none) if it doesn't know,
+                 * so return NULL in that case */
+                if (strcmp (version, "(none)") == 0) {
+                        g_free (version);
+                        version = NULL;
+                }
+
                 g_free (output);
 
                 goto out;
